#! /usr/bin/nodejs

'use strict';

const Fax2 = require('./fax2.js');
const credentials = require('./credentials');

let fax2 = new Fax2();
fax2.username = credentials.username;
fax2.password = credentials.password;

let last_received_at = Fax2.date_add_seconds(new Date(),-7200);
let last_seen = {};

// 300 seconds is the maximum guaranteed by the API specification, from
// a new entry's received_at time and the latest received_at time
// returned so far.
const MARGIN = 300;

function run_once() {
	return fax2.received_faxes({from_time: last_received_at}).then((faxlist) => {
		let write_promise = new Promise((resolve,reject) => resolve());
		if(faxlist.length) {
			let i;
			for(i=0;i<faxlist.length;i++) {
				let entry = faxlist[i];
				let id = entry.id;
				if(!last_seen[id]) {
					let receive_time = entry.received_at.toISOString().
						replace(/[^0-9]/g,"").substring(0,12);
					let filename = `received-${receive_time}-${id}.pdf`;
					
					write_promise = write_promise.then(() => {
						return fax2.write_received_fax_pdf(id,filename).then(() => {
							console.log(`received fax ${id} written as ${filename}`);
							last_seen[id] = 1;
						});
					});
				}
			}
			
			write_promise = write_promise.then(() => {
				last_seen = {};
				let i;
				for(i=0;i<faxlist.length;i++) last_seen[faxlist[i].id] = 1;
				let new_last_received_at = Fax2.date_add_seconds(
					faxlist.map((entry) => entry.received_at).
						reduce((a,b) => (a>b)?a:b),
					-MARGIN
				);
				if(new_last_received_at > last_received_at)
					last_received_at = new_last_received_at;
			});
		}
		return write_promise;
	}).catch((e) => {
		console.log("error: ",e);
	});
}

let run = () => {
	run_once().then(() => {
		setTimeout(() => run(),30000);
	});
};

run();
